@@ -7,6 +7,8 @@
 */
 
 #include <QApplication>
+using namespace Qt::Literals::StringLiterals;
+
 #include <QCommandLineParser>
 #include <QStandardPaths>
 
@@ -22,12 +24,11 @@ int main(int argc, char *argv[])
     parser.process(app);
 
     auto combo = new KPIM::KCheckComboBox(nullptr);
-    combo->addItems(QStringList() << QStringLiteral("KDE") << QStringLiteral("Mac OSX") << QStringLiteral("Windows") << QStringLiteral("XFCE")
-                                  << QStringLiteral("FVWM") << QStringLiteral("TWM"));
-    combo->setCheckedItems(QStringList() << QStringLiteral("KDE") << QStringLiteral("Mac OSX") << QStringLiteral("Windows"));
+    combo->addItems(QStringList() << u"KDE"_s << u"Mac OSX"_s << QStringLiteral("Windows") << QStringLiteral("XFCE") << u"FVWM"_s << u"TWM"_s);
+    combo->setCheckedItems(QStringList() << u"KDE"_s << u"Mac OSX"_s << QStringLiteral("Windows"));
     combo->resize(400, 20);
     combo->setSqueezeText(true);
-    combo->setDefaultText(QStringLiteral("Default text"));
+    combo->setDefaultText(u"Default text"_s);
     combo->show();
 
     return app.exec();
